HostWithStore

Trait HostWithStore 

pub trait HostWithStore: HasData + Send {
    // Required method
    fn get<T: Send>(
        accessor: &Accessor<T, Self>,
        name: String,
    ) -> impl Future<Output = Result<String, Error>> + Send;
}

Required Methods

fn get<T: Send>( accessor: &Accessor<T, Self>, name: String, ) -> impl Future<Output = Result<String, Error>> + Send

Get an application variable value for the current component.

The name must match one defined in in the component manifest.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors